@@ -1,6 +1,5 @@
 from .logger import logger
 import boto3
-import os
 
 client_ecs = boto3.client("ecs")
 my_session = boto3.session.Session()
@@ -59,9 +58,6 @@ def _create_service(*, proc_set, proc, task_definition_arn):
         )
     )
 
-def _env_dump():
-    return [ dict(name = k, value = v) for k,v in os.environ ]
-
 def _register_task_definition(*, proc_set, proc):
     return client_ecs.register_task_definition(
         family = proc.name,
@@ -87,7 +83,9 @@ def _register_task_definition(*, proc_set, proc):
                 containerPort = proc.port,
                 hostPort = proc.port
             )],
-            environment = _env_dump()
+            environment = [
+                dict(name = k, value = v) for k,v in proc_set.environment.items()
+            ]
         )]
     )["taskDefinition"]["taskDefinitionArn"]
 
